# tvb-ext-xircuits

This is a jupyterlab extension built as a prototype for building TVB workflows in a visual and interactive manner. It 
extends the already existent [Xircuits](https://xircuits.io/) jupyterlab extension by adding TVB components and new features on top.

There is an alpha version released for testing purposes:

    pip install tvb-ext-xircuits

